#if !defined(__GHCPLATFORM_H__)
#define __GHCPLATFORM_H__

#define GHC_STAGE (1 + 1)

#define BuildPlatform_TYPE  x86_64_unknown_openbsd
#define HostPlatform_TYPE   x86_64_unknown_openbsd

#define x86_64_unknown_openbsd_BUILD  1
#define x86_64_unknown_openbsd_HOST  1

#define x86_64_BUILD_ARCH  1
#define x86_64_HOST_ARCH  1
#define BUILD_ARCH  "x86_64"
#define HOST_ARCH  "x86_64"

#define openbsd_BUILD_OS  1
#define openbsd_HOST_OS  1
#define BUILD_OS  "openbsd"
#define HOST_OS  "openbsd"

#define unknown_BUILD_VENDOR  1
#define unknown_HOST_VENDOR  1
#define BUILD_VENDOR  "unknown"
#define HOST_VENDOR  "unknown"


#endif /* __GHCPLATFORM_H__ */
